"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .partitionlimits import PartitionLimits, PartitionLimitsTypedDict
from .partitionstats import PartitionStats, PartitionStatsTypedDict
from datetime import datetime
from pydantic import model_serializer
from ragie.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from typing import Any, Dict, List, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


PartitionDetailMetadataSchemaTypedDict = TypeAliasType(
    "PartitionDetailMetadataSchemaTypedDict",
    Union[str, int, bool, List[str], Dict[str, Any]],
)


PartitionDetailMetadataSchema = TypeAliasType(
    "PartitionDetailMetadataSchema", Union[str, int, bool, List[str], Dict[str, Any]]
)


class PartitionDetailTypedDict(TypedDict):
    name: str
    is_default: bool
    description: Nullable[str]
    context_aware: bool
    metadata_schema: Nullable[Dict[str, PartitionDetailMetadataSchemaTypedDict]]
    limits: PartitionLimitsTypedDict
    stats: PartitionStatsTypedDict
    limit_exceeded_at: NotRequired[Nullable[datetime]]
    r"""Timestamp when the partition exceeded its limits, if applicable."""


class PartitionDetail(BaseModel):
    name: str

    is_default: bool

    description: Nullable[str]

    context_aware: bool

    metadata_schema: Nullable[Dict[str, PartitionDetailMetadataSchema]]

    limits: PartitionLimits

    stats: PartitionStats

    limit_exceeded_at: OptionalNullable[datetime] = UNSET
    r"""Timestamp when the partition exceeded its limits, if applicable."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["limit_exceeded_at"]
        nullable_fields = ["limit_exceeded_at", "description", "metadata_schema"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class CodeInterpreterOutputLogsTypedDict(TypedDict):
    logs: str
    r"""The logs output from the code interpreter."""
    type: Literal["logs"]


class CodeInterpreterOutputLogs(BaseModel):
    logs: str
    r"""The logs output from the code interpreter."""

    TYPE: Annotated[
        Annotated[Optional[Literal["logs"]], AfterValidator(validate_const("logs"))],
        pydantic.Field(alias="type"),
    ] = "logs"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .filesearchresult import FileSearchResult, FileSearchResultTypedDict
from enum import Enum
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FileSearchOutputStatus(str, Enum):
    IN_PROGRESS = "in_progress"
    SEARCHING = "searching"
    INCOMPLETE = "incomplete"
    COMPLETED = "completed"
    FAILED = "failed"


class FileSearchOutputTypedDict(TypedDict):
    id: str
    queries: List[str]
    r"""The queries used to search for files."""
    results: List[FileSearchResultTypedDict]
    r"""The results of the file search tool call."""
    status: NotRequired[FileSearchOutputStatus]
    type: Literal["file_search_call"]


class FileSearchOutput(BaseModel):
    id: str

    queries: List[str]
    r"""The queries used to search for files."""

    results: List[FileSearchResult]
    r"""The results of the file search tool call."""

    status: Optional[FileSearchOutputStatus] = FileSearchOutputStatus.SEARCHING

    TYPE: Annotated[
        Annotated[
            Literal["file_search_call"],
            AfterValidator(validate_const("file_search_call")),
        ],
        pydantic.Field(alias="type"),
    ] = "file_search_call"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class FileSearchResultTypedDict(TypedDict):
    file_id: str
    r"""The unique ID of the document."""
    filename: str
    r"""The name of the document."""
    score: float
    r"""The relevance score of the chunk - a value between 0 and 1."""
    text: str
    r"""The text content of the chunk."""
    attributes: Dict[str, Any]
    r"""The attributes of the chunk."""


class FileSearchResult(BaseModel):
    file_id: str
    r"""The unique ID of the document."""

    filename: str
    r"""The name of the document."""

    score: float
    r"""The relevance score of the chunk - a value between 0 and 1."""

    text: str
    r"""The text content of the chunk."""

    attributes: Dict[str, Any]
    r"""The attributes of the chunk."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from ragie import models, utils
from ragie._hooks import HookContext
from ragie.types import BaseModel, OptionalNullable, UNSET
from ragie.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional, Union, cast


class Responses(BaseSDK):
    def create(
        self,
        *,
        request: Union[models.Request, models.RequestTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Response:
        r"""Create Response

        Create a response. This will generate an LLM or agentic response. At this time the only supported model is `deep-search`. Responses may be streamed or returned synchronously. The `retrieve` tool is currently the only supported tool, more tools will be added in the future. A single partition may be provided in the retrieve tool. If omitted the `default` partition is used.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.Request)
        request = cast(models.Request, request)

        req = self._build_request(
            method="POST",
            path="/responses",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.Request
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="create_response_responses_post",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["401", "402", "422", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Response, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                models.HTTPValidationErrorData, http_res
            )
            raise models.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, ["401", "402", "429"], "application/json"):
            response_data = unmarshal_json_response(models.ErrorMessageData, http_res)
            raise models.ErrorMessage(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(models.ErrorMessageData, http_res)
            raise models.ErrorMessage(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError("API error occurred", http_res, http_res_text)

        raise models.SDKError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        request: Union[models.Request, models.RequestTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Response:
        r"""Create Response

        Create a response. This will generate an LLM or agentic response. At this time the only supported model is `deep-search`. Responses may be streamed or returned synchronously. The `retrieve` tool is currently the only supported tool, more tools will be added in the future. A single partition may be provided in the retrieve tool. If omitted the `default` partition is used.

        :param request: The request object to send.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        if not isinstance(request, BaseModel):
            request = utils.unmarshal(request, models.Request)
        request = cast(models.Request, request)

        req = self._build_request_async(
            method="POST",
            path="/responses",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.Request
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="create_response_responses_post",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["401", "402", "422", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Response, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                models.HTTPValidationErrorData, http_res
            )
            raise models.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, ["401", "402", "429"], "application/json"):
            response_data = unmarshal_json_response(models.ErrorMessageData, http_res)
            raise models.ErrorMessage(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(models.ErrorMessageData, http_res)
            raise models.ErrorMessage(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError("API error occurred", http_res, http_res_text)

        raise models.SDKError("Unexpected response received", http_res)

    def get(
        self,
        *,
        response_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Response:
        r"""Get Response

        Get a response by its ID. This will return the response and its status. If the response is still in progress, the status will be `in_progress`. If the response is completed, the status will be `completed`. If the response is failed, the status will be `failed`.

        :param response_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetResponseResponsesResponseIDGetRequest(
            response_id=response_id,
        )

        req = self._build_request(
            method="GET",
            path="/responses/{response_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_response_responses__response_id__get",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["401", "402", "422", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Response, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                models.HTTPValidationErrorData, http_res
            )
            raise models.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, ["401", "402", "429"], "application/json"):
            response_data = unmarshal_json_response(models.ErrorMessageData, http_res)
            raise models.ErrorMessage(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(models.ErrorMessageData, http_res)
            raise models.ErrorMessage(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError("API error occurred", http_res, http_res_text)

        raise models.SDKError("Unexpected response received", http_res)

    async def get_async(
        self,
        *,
        response_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Response:
        r"""Get Response

        Get a response by its ID. This will return the response and its status. If the response is still in progress, the status will be `in_progress`. If the response is completed, the status will be `completed`. If the response is failed, the status will be `failed`.

        :param response_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetResponseResponsesResponseIDGetRequest(
            response_id=response_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/responses/{response_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="get_response_responses__response_id__get",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["401", "402", "422", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.Response, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                models.HTTPValidationErrorData, http_res
            )
            raise models.HTTPValidationError(response_data, http_res)
        if utils.match_response(http_res, ["401", "402", "429"], "application/json"):
            response_data = unmarshal_json_response(models.ErrorMessageData, http_res)
            raise models.ErrorMessage(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(models.ErrorMessageData, http_res)
            raise models.ErrorMessage(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError("API error occurred", http_res, http_res_text)

        raise models.SDKError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .reasoningsummary import ReasoningSummary, ReasoningSummaryTypedDict
from .reasoningtext import ReasoningText, ReasoningTextTypedDict
from enum import Enum
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ReasoningOutputStatus(str, Enum):
    IN_PROGRESS = "in_progress"
    COMPLETED = "completed"
    INCOMPLETE = "incomplete"


class ReasoningOutputTypedDict(TypedDict):
    id: str
    r"""The unique ID of the reasoning output."""
    summary: List[ReasoningSummaryTypedDict]
    r"""The summary of the reasoning."""
    content: List[ReasoningTextTypedDict]
    r"""The content of the reasoning."""
    encrypted_content: str
    r"""The encrypted content of the reasoning output."""
    type: Literal["reasoning"]
    status: NotRequired[ReasoningOutputStatus]


class ReasoningOutput(BaseModel):
    id: str
    r"""The unique ID of the reasoning output."""

    summary: List[ReasoningSummary]
    r"""The summary of the reasoning."""

    content: List[ReasoningText]
    r"""The content of the reasoning."""

    encrypted_content: str
    r"""The encrypted content of the reasoning output."""

    TYPE: Annotated[
        Annotated[
            Optional[Literal["reasoning"]], AfterValidator(validate_const("reasoning"))
        ],
        pydantic.Field(alias="type"),
    ] = "reasoning"

    status: Optional[ReasoningOutputStatus] = ReasoningOutputStatus.COMPLETED



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SearchEffort(str, Enum):
    LOW = "low"
    MEDIUM = "medium"
    HIGH = "high"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class ReasoningTextTypedDict(TypedDict):
    text: str
    r"""The text of the reasoning."""
    type: Literal["reasoning_text"]


class ReasoningText(BaseModel):
    text: str
    r"""The text of the reasoning."""

    TYPE: Annotated[
        Annotated[
            Optional[Literal["reasoning_text"]],
            AfterValidator(validate_const("reasoning_text")),
        ],
        pydantic.Field(alias="type"),
    ] = "reasoning_text"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from pydantic import model_serializer
from ragie.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from typing import Any, Dict, List, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


UpdatePartitionParamsMetadataSchemaTypedDict = TypeAliasType(
    "UpdatePartitionParamsMetadataSchemaTypedDict",
    Union[str, int, bool, List[str], Dict[str, Any]],
)


UpdatePartitionParamsMetadataSchema = TypeAliasType(
    "UpdatePartitionParamsMetadataSchema",
    Union[str, int, bool, List[str], Dict[str, Any]],
)


class UpdatePartitionParamsTypedDict(TypedDict):
    context_aware: NotRequired[Nullable[bool]]
    r"""Enable context-aware descriptions for the partition."""
    description: NotRequired[Nullable[str]]
    r"""Description of the partition."""
    metadata_schema: NotRequired[
        Nullable[Dict[str, UpdatePartitionParamsMetadataSchemaTypedDict]]
    ]
    r"""Metadata schema for the partition. This is an optional subset of the metadata of documents in the partition, defined as JSON Schema, that can be used in filter generatation. Providing detailed descriptions of the fields in the schema can be helpful for LLMs generating filters dynamically."""


class UpdatePartitionParams(BaseModel):
    context_aware: OptionalNullable[bool] = UNSET
    r"""Enable context-aware descriptions for the partition."""

    description: OptionalNullable[str] = UNSET
    r"""Description of the partition."""

    metadata_schema: OptionalNullable[
        Dict[str, UpdatePartitionParamsMetadataSchema]
    ] = UNSET
    r"""Metadata schema for the partition. This is an optional subset of the metadata of documents in the partition, defined as JSON Schema, that can be used in filter generatation. Providing detailed descriptions of the fields in the schema can be helpful for LLMs generating filters dynamically."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["context_aware", "description", "metadata_schema"]
        nullable_fields = ["context_aware", "description", "metadata_schema"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


class ReasoningSummaryTypedDict(TypedDict):
    summary: str
    r"""The summary of the reasoning."""
    type: Literal["summary"]


class ReasoningSummary(BaseModel):
    summary: str
    r"""The summary of the reasoning."""

    TYPE: Annotated[
        Annotated[
            Optional[Literal["summary"]], AfterValidator(validate_const("summary"))
        ],
        pydantic.Field(alias="type"),
    ] = "summary"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .webhookendpoint import WebhookEndpoint, WebhookEndpointTypedDict
from ragie.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class WebhookEndpointListTypedDict(TypedDict):
    pagination: PaginationTypedDict
    webhook_endpoints: List[WebhookEndpointTypedDict]


class WebhookEndpointList(BaseModel):
    pagination: Pagination

    webhook_endpoints: List[WebhookEndpoint]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
import io
import pydantic
from pydantic import model_serializer
from ragie.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from ragie.utils import FieldMetadata, MultipartFormMetadata
from typing import Dict, IO, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class Two2TypedDict(TypedDict):
    pass


class Two2(BaseModel):
    pass


class Two1(str, Enum):
    HI_RES = "hi_res"
    FAST = "fast"


TwoTypedDict = TypeAliasType("TwoTypedDict", Union[Two2TypedDict, Two1])


Two = TypeAliasType("Two", Union[Two2, Two1])


class ModeStatic(str, Enum):
    HI_RES = "hi_res"
    FAST = "fast"


class ModeVideo(str, Enum):
    AUDIO_ONLY = "audio_only"
    VIDEO_ONLY = "video_only"
    AUDIO_VIDEO = "audio_video"


class OneTypedDict(TypedDict):
    static: NotRequired[Nullable[ModeStatic]]
    audio: NotRequired[Nullable[bool]]
    video: NotRequired[Nullable[ModeVideo]]


class One(BaseModel):
    static: OptionalNullable[ModeStatic] = UNSET

    audio: OptionalNullable[bool] = UNSET

    video: OptionalNullable[ModeVideo] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["static", "audio", "video"]
        nullable_fields = ["static", "audio", "video"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


ModeTypedDict = TypeAliasType("ModeTypedDict", Union[OneTypedDict, TwoTypedDict])
r"""Partition strategy for the document. Different strategies exist for textual, audio and video file types and you can set the strategy you want for  each file type, or just for textual types.  For textual documents the options are `'hi_res'` or `'fast'`. When set to `'hi_res'`, images and tables will be extracted from the document. `'fast'` will only extract text. `'fast'` may be up to 20x faster than `'hi_res'`. `hi_res` is only applicable for Word documents, PDFs, Images, and PowerPoints. Images will always be processed in `hi_res`. If `hi_res` is set for an unsupported document type, it will be processed and billed in `fast` mode.  For audio files, the options are true or false. True if you want to process audio, false otherwise.          For video files, the options are `'audio_only'`, `'video_only'`, `'audio_video'`. `'audio_only'` will extract just the audio part of the video. `'video_only'` will similarly just extract the video part, ignoring audio. `'audio_video'` will extract both audio and video.  To process all media types at the highest quality, use `'all'`.  When you specify audio or video stategies, the format must be a JSON object. In this case, textual documents are denoted by the key \"static\". If you omit a key, that document type won't be processd.  See examples below.  Examples  Textual documents only     \"fast\"  Video documents only {     \"video\": \"audio_video\" }  Specify multiple document types {     \"static\": \"hi_res\",     \"audio\": true,     \"video\": \"video_only\" }  Specify only textual or audio document types {     \"static\": \"fast\",     \"audio\": true }  Highest quality processing for all media types     \"all\" """


Mode = TypeAliasType("Mode", Union[One, Two])
r"""Partition strategy for the document. Different strategies exist for textual, audio and video file types and you can set the strategy you want for  each file type, or just for textual types.  For textual documents the options are `'hi_res'` or `'fast'`. When set to `'hi_res'`, images and tables will be extracted from the document. `'fast'` will only extract text. `'fast'` may be up to 20x faster than `'hi_res'`. `hi_res` is only applicable for Word documents, PDFs, Images, and PowerPoints. Images will always be processed in `hi_res`. If `hi_res` is set for an unsupported document type, it will be processed and billed in `fast` mode.  For audio files, the options are true or false. True if you want to process audio, false otherwise.          For video files, the options are `'audio_only'`, `'video_only'`, `'audio_video'`. `'audio_only'` will extract just the audio part of the video. `'video_only'` will similarly just extract the video part, ignoring audio. `'audio_video'` will extract both audio and video.  To process all media types at the highest quality, use `'all'`.  When you specify audio or video stategies, the format must be a JSON object. In this case, textual documents are denoted by the key \"static\". If you omit a key, that document type won't be processd.  See examples below.  Examples  Textual documents only     \"fast\"  Video documents only {     \"video\": \"audio_video\" }  Specify multiple document types {     \"static\": \"hi_res\",     \"audio\": true,     \"video\": \"video_only\" }  Specify only textual or audio document types {     \"static\": \"fast\",     \"audio\": true }  Highest quality processing for all media types     \"all\" """


MetadataTypedDict = TypeAliasType(
    "MetadataTypedDict", Union[str, float, bool, List[str]]
)


Metadata = TypeAliasType("Metadata", Union[str, float, bool, List[str]])


class FileTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class File(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="fileName"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class CreateDocumentParamsTypedDict(TypedDict):
    file: FileTypedDict
    r"""The binary file to upload, extract, and index for retrieval. The following file types are supported: Plain Text: `.eml` `.html` `.json` `.md` `.msg` `.rst` `.rtf` `.txt` `.xml`
    Images: `.png` `.webp` `.jpg` `.jpeg` `.tiff` `.bmp` `.heic`
    Documents: `.csv` `.doc` `.docx` `.epub` `.epub+zip` `.odt` `.pdf` `.ppt` `.pptx` `.tsv` `.xlsx` `.xls`. PDF files over 2000 pages are not supported in hi_res mode.
    """
    mode: NotRequired[ModeTypedDict]
    r"""Partition strategy for the document. Different strategies exist for textual, audio and video file types and you can set the strategy you want for  each file type, or just for textual types.  For textual documents the options are `'hi_res'` or `'fast'`. When set to `'hi_res'`, images and tables will be extracted from the document. `'fast'` will only extract text. `'fast'` may be up to 20x faster than `'hi_res'`. `hi_res` is only applicable for Word documents, PDFs, Images, and PowerPoints. Images will always be processed in `hi_res`. If `hi_res` is set for an unsupported document type, it will be processed and billed in `fast` mode.  For audio files, the options are true or false. True if you want to process audio, false otherwise.          For video files, the options are `'audio_only'`, `'video_only'`, `'audio_video'`. `'audio_only'` will extract just the audio part of the video. `'video_only'` will similarly just extract the video part, ignoring audio. `'audio_video'` will extract both audio and video.  To process all media types at the highest quality, use `'all'`.  When you specify audio or video stategies, the format must be a JSON object. In this case, textual documents are denoted by the key \"static\". If you omit a key, that document type won't be processd.  See examples below.  Examples  Textual documents only     \"fast\"  Video documents only {     \"video\": \"audio_video\" }  Specify multiple document types {     \"static\": \"hi_res\",     \"audio\": true,     \"video\": \"video_only\" }  Specify only textual or audio document types {     \"static\": \"fast\",     \"audio\": true }  Highest quality processing for all media types     \"all\" """
    metadata: NotRequired[Dict[str, MetadataTypedDict]]
    r"""Metadata for the document. Keys must be strings. Values may be strings, numbers, booleans, or lists of strings. Numbers may be integers or floating point and will be converted to 64 bit floating point. 1000 total values are allowed. Each item in an array counts towards the total. The following keys are reserved for internal use: `document_id`, `document_type`, `document_source`, `document_name`, `document_uploaded_at`, `start_time`, `end_time`, `chunk_content_type`."""
    external_id: NotRequired[str]
    r"""An optional identifier for the document. A common value might be an id in an external system or the URL where the source file may be found."""
    name: NotRequired[str]
    r"""An optional name for the document. If set, the document will have this name. Otherwise it will default to the file's name."""
    partition: NotRequired[str]
    r"""An optional partition identifier. Documents can be scoped to a partition. Partitions must be lowercase alphanumeric and may only include the special characters `_` and `-`.  A partition is created any time a document is created."""


class CreateDocumentParams(BaseModel):
    file: Annotated[File, FieldMetadata(multipart=MultipartFormMetadata(file=True))]
    r"""The binary file to upload, extract, and index for retrieval. The following file types are supported: Plain Text: `.eml` `.html` `.json` `.md` `.msg` `.rst` `.rtf` `.txt` `.xml`
    Images: `.png` `.webp` `.jpg` `.jpeg` `.tiff` `.bmp` `.heic`
    Documents: `.csv` `.doc` `.docx` `.epub` `.epub+zip` `.odt` `.pdf` `.ppt` `.pptx` `.tsv` `.xlsx` `.xls`. PDF files over 2000 pages are not supported in hi_res mode.
    """

    mode: Annotated[
        Optional[Mode], FieldMetadata(multipart=MultipartFormMetadata(json=True))
    ] = None
    r"""Partition strategy for the document. Different strategies exist for textual, audio and video file types and you can set the strategy you want for  each file type, or just for textual types.  For textual documents the options are `'hi_res'` or `'fast'`. When set to `'hi_res'`, images and tables will be extracted from the document. `'fast'` will only extract text. `'fast'` may be up to 20x faster than `'hi_res'`. `hi_res` is only applicable for Word documents, PDFs, Images, and PowerPoints. Images will always be processed in `hi_res`. If `hi_res` is set for an unsupported document type, it will be processed and billed in `fast` mode.  For audio files, the options are true or false. True if you want to process audio, false otherwise.          For video files, the options are `'audio_only'`, `'video_only'`, `'audio_video'`. `'audio_only'` will extract just the audio part of the video. `'video_only'` will similarly just extract the video part, ignoring audio. `'audio_video'` will extract both audio and video.  To process all media types at the highest quality, use `'all'`.  When you specify audio or video stategies, the format must be a JSON object. In this case, textual documents are denoted by the key \"static\". If you omit a key, that document type won't be processd.  See examples below.  Examples  Textual documents only     \"fast\"  Video documents only {     \"video\": \"audio_video\" }  Specify multiple document types {     \"static\": \"hi_res\",     \"audio\": true,     \"video\": \"video_only\" }  Specify only textual or audio document types {     \"static\": \"fast\",     \"audio\": true }  Highest quality processing for all media types     \"all\" """

    metadata: Annotated[
        Optional[Dict[str, Metadata]],
        FieldMetadata(multipart=MultipartFormMetadata(json=True)),
    ] = None
    r"""Metadata for the document. Keys must be strings. Values may be strings, numbers, booleans, or lists of strings. Numbers may be integers or floating point and will be converted to 64 bit floating point. 1000 total values are allowed. Each item in an array counts towards the total. The following keys are reserved for internal use: `document_id`, `document_type`, `document_source`, `document_name`, `document_uploaded_at`, `start_time`, `end_time`, `chunk_content_type`."""

    external_id: Annotated[Optional[str], FieldMetadata(multipart=True)] = None
    r"""An optional identifier for the document. A common value might be an id in an external system or the URL where the source file may be found."""

    name: Annotated[Optional[str], FieldMetadata(multipart=True)] = None
    r"""An optional name for the document. If set, the document will have this name. Otherwise it will default to the file's name."""

    partition: Annotated[Optional[str], FieldMetadata(multipart=True)] = None
    r"""An optional partition identifier. Documents can be scoped to a partition. Partitions must be lowercase alphanumeric and may only include the special characters `_` and `-`.  A partition is created any time a document is created."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ragieevidence import RagieEvidence, RagieEvidenceTypedDict
from .searcheffort import SearchEffort
from ragie.types import BaseModel
from typing import Any, Dict, List
from typing_extensions import TypedDict


class QueryDetailsTypedDict(TypedDict):
    query: str
    search_effort: SearchEffort
    metadata_filter: Dict[str, Any]
    search_results: List[RagieEvidenceTypedDict]


class QueryDetails(BaseModel):
    query: str

    search_effort: SearchEffort

    metadata_filter: Dict[str, Any]

    search_results: List[RagieEvidence]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updatewebhookendpointpayload import (
    UpdateWebhookEndpointPayload,
    UpdateWebhookEndpointPayloadTypedDict,
)
from ragie.types import BaseModel
from ragie.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateWebhookEndpointRequestTypedDict(TypedDict):
    endpoint_id: str
    update_webhook_endpoint_payload: UpdateWebhookEndpointPayloadTypedDict


class UpdateWebhookEndpointRequest(BaseModel):
    endpoint_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_webhook_endpoint_payload: Annotated[
        UpdateWebhookEndpointPayload,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .codeinterpreteroutputlogs import (
    CodeInterpreterOutputLogs,
    CodeInterpreterOutputLogsTypedDict,
)
from enum import Enum
import pydantic
from pydantic.functional_validators import AfterValidator
from ragie.types import BaseModel
from ragie.utils import validate_const
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CodeInterpreterOutputStatus(str, Enum):
    IN_PROGRESS = "in_progress"
    INTERPRETING = "interpreting"
    COMPLETED = "completed"
    INCOMPLETE = "incomplete"
    FAILED = "failed"


class CodeInterpreterOutputTypedDict(TypedDict):
    id: str
    r"""The unique ID of the code interpreter tool call."""
    code: str
    r"""The code executed by the code interpreter."""
    container_id: str
    r"""The ID of the container used to run the code."""
    outputs: List[CodeInterpreterOutputLogsTypedDict]
    r"""The outputs generated by the code interpreter, such as logs or images."""
    type: Literal["code_interpreter_output"]
    status: NotRequired[CodeInterpreterOutputStatus]


class CodeInterpreterOutput(BaseModel):
    id: str
    r"""The unique ID of the code interpreter tool call."""

    code: str
    r"""The code executed by the code interpreter."""

    container_id: str
    r"""The ID of the container used to run the code."""

    outputs: List[CodeInterpreterOutputLogs]
    r"""The outputs generated by the code interpreter, such as logs or images."""

    TYPE: Annotated[
        Annotated[
            Optional[Literal["code_interpreter_output"]],
            AfterValidator(validate_const("code_interpreter_output")),
        ],
        pydantic.Field(alias="type"),
    ] = "code_interpreter_output"

    status: Optional[CodeInterpreterOutputStatus] = (
        CodeInterpreterOutputStatus.COMPLETED
    )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from pydantic import model_serializer
from ragie.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from typing import Any, Dict, List, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


CreatePartitionParamsMetadataSchemaTypedDict = TypeAliasType(
    "CreatePartitionParamsMetadataSchemaTypedDict",
    Union[str, int, bool, List[str], Dict[str, Any]],
)


CreatePartitionParamsMetadataSchema = TypeAliasType(
    "CreatePartitionParamsMetadataSchema",
    Union[str, int, bool, List[str], Dict[str, Any]],
)


class CreatePartitionParamsTypedDict(TypedDict):
    name: str
    description: NotRequired[Nullable[str]]
    r"""Description of the partition. Automatic description generation can be enabled in the web dashboard."""
    pages_hosted_limit_monthly: NotRequired[Nullable[int]]
    r"""Monthly limit of hosted pages added in the current month in the partition."""
    pages_processed_limit_monthly: NotRequired[Nullable[int]]
    r"""Monthly limit, in pages, for processed documents in the partition."""
    pages_hosted_limit_max: NotRequired[Nullable[int]]
    r"""Maximum limit, in pages, for hosted documents in the partition."""
    pages_processed_limit_max: NotRequired[Nullable[int]]
    r"""Maximum limit, in pages, for processed documents in the partition."""
    audio_processed_limit_monthly: NotRequired[Nullable[int]]
    r"""Monthly limit, in minutes, for audio processing in the partition."""
    audio_processed_limit_max: NotRequired[Nullable[int]]
    r"""Maximum limit, in minutes, for audio processing in the partition."""
    video_processed_limit_monthly: NotRequired[Nullable[int]]
    r"""Monthly limit, in minutes, for video processing in the partition."""
    video_processed_limit_max: NotRequired[Nullable[int]]
    r"""Maximum limit, in minutes, for video processing in the partition."""
    media_streamed_limit_monthly: NotRequired[Nullable[int]]
    r"""Monthly limit, in MBs, for media streamed from the partition."""
    media_streamed_limit_max: NotRequired[Nullable[int]]
    r"""Maximum limit, in MBs, for media streamed from the partition."""
    media_hosted_limit_monthly: NotRequired[Nullable[int]]
    r"""Monthly limit, in MBs, for media hosted in the partition."""
    media_hosted_limit_max: NotRequired[Nullable[int]]
    r"""Maximum limit, in MBs, for media hosted in the partition."""
    metadata_schema: NotRequired[
        Nullable[Dict[str, CreatePartitionParamsMetadataSchemaTypedDict]]
    ]
    r"""Metadata schema for the partition. This is an optional subset of the metadata of documents in the partition, defined as JSON Schema, that can be used in filter generatation. Providing detailed descriptions of the fields in the schema can be helpful for LLMs generating filters dynamically."""


class CreatePartitionParams(BaseModel):
    name: str

    description: OptionalNullable[str] = UNSET
    r"""Description of the partition. Automatic description generation can be enabled in the web dashboard."""

    pages_hosted_limit_monthly: OptionalNullable[int] = UNSET
    r"""Monthly limit of hosted pages added in the current month in the partition."""

    pages_processed_limit_monthly: OptionalNullable[int] = UNSET
    r"""Monthly limit, in pages, for processed documents in the partition."""

    pages_hosted_limit_max: OptionalNullable[int] = UNSET
    r"""Maximum limit, in pages, for hosted documents in the partition."""

    pages_processed_limit_max: OptionalNullable[int] = UNSET
    r"""Maximum limit, in pages, for processed documents in the partition."""

    audio_processed_limit_monthly: OptionalNullable[int] = UNSET
    r"""Monthly limit, in minutes, for audio processing in the partition."""

    audio_processed_limit_max: OptionalNullable[int] = UNSET
    r"""Maximum limit, in minutes, for audio processing in the partition."""

    video_processed_limit_monthly: OptionalNullable[int] = UNSET
    r"""Monthly limit, in minutes, for video processing in the partition."""

    video_processed_limit_max: OptionalNullable[int] = UNSET
    r"""Maximum limit, in minutes, for video processing in the partition."""

    media_streamed_limit_monthly: OptionalNullable[int] = UNSET
    r"""Monthly limit, in MBs, for media streamed from the partition."""

    media_streamed_limit_max: OptionalNullable[int] = UNSET
    r"""Maximum limit, in MBs, for media streamed from the partition."""

    media_hosted_limit_monthly: OptionalNullable[int] = UNSET
    r"""Monthly limit, in MBs, for media hosted in the partition."""

    media_hosted_limit_max: OptionalNullable[int] = UNSET
    r"""Maximum limit, in MBs, for media hosted in the partition."""

    metadata_schema: OptionalNullable[
        Dict[str, CreatePartitionParamsMetadataSchema]
    ] = UNSET
    r"""Metadata schema for the partition. This is an optional subset of the metadata of documents in the partition, defined as JSON Schema, that can be used in filter generatation. Providing detailed descriptions of the fields in the schema can be helpful for LLMs generating filters dynamically."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "description",
            "pages_hosted_limit_monthly",
            "pages_processed_limit_monthly",
            "pages_hosted_limit_max",
            "pages_processed_limit_max",
            "audio_processed_limit_monthly",
            "audio_processed_limit_max",
            "video_processed_limit_monthly",
            "video_processed_limit_max",
            "media_streamed_limit_monthly",
            "media_streamed_limit_max",
            "media_hosted_limit_monthly",
            "media_hosted_limit_max",
            "metadata_schema",
        ]
        nullable_fields = [
            "description",
            "pages_hosted_limit_monthly",
            "pages_processed_limit_monthly",
            "pages_hosted_limit_max",
            "pages_processed_limit_max",
            "audio_processed_limit_monthly",
            "audio_processed_limit_max",
            "video_processed_limit_monthly",
            "video_processed_limit_max",
            "media_streamed_limit_monthly",
            "media_streamed_limit_max",
            "media_hosted_limit_monthly",
            "media_hosted_limit_max",
            "metadata_schema",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
